cpTestFn() and
cpTestCn() if b is set to NULL.bOptEmpProc(x, m=5, weights = c("parzen", "bartlett"),
L.method=c("max","median","mean","min"))ncol(x)) involved in the estimation of the bandwidth
parameter; see Section 5 of the third reference. The number of
points L involved
in the estimation of the bandwidth parameter is computed; see
Section 5 of the third reference.Acknowledgment: Part of the code of the function results from an adaptation of R code of C. Parmeter and J. Racine, itself an adaptation of Matlab code by A. Patton.
D.N. Politis, H. White and A.J. Patton (2004), Correction: Automatic block-length selection for the dependent bootstrap, Econometric Reviews 28(4):372-375.
A. B
cpTestFn(), cpTestCn().